Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(106)

Unified Diff: components/autofill/core/browser/autofill_manager.h

Issue 2894333002: Pass active_chrome_experiments in payments RPC. (Closed)
Patch Set: Adds feature to active_chrome_experiments only if feature was triggered. Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/autofill/core/browser/autofill_manager.h
diff --git a/components/autofill/core/browser/autofill_manager.h b/components/autofill/core/browser/autofill_manager.h
index 66850cf29a5e48ef73ef0b553dd4139a712948dc..a0d7514073a9612eb6f82f1b25cfc1e5a75d9fec 100644
--- a/components/autofill/core/browser/autofill_manager.h
+++ b/components/autofill/core/browser/autofill_manager.h
@@ -432,13 +432,15 @@ class AutofillManager : public AutofillDownloadManager::Observer,
// Examines |card| and the stored profiles and if a candidate set of profiles
// is found that matches the client-side validation rules, assigns the values
// to |profiles| and returns 0. If no valid set can be found, returns the
// failure reasons and, if applicable, the RAPPOR metric to log to
// |rappor_metric_name|. The return value is a bitmask of
// |AutofillMetrics::CardUploadDecisionMetric|.
- int GetProfilesForCreditCardUpload(const CreditCard& card,
- std::vector<AutofillProfile>* profiles,
- std::string* rappor_metric_name) const;
+ int SetProfilesForCreditCardUpload(
+ const CreditCard& card,
+ payments::PaymentsClient::UploadRequestDetails* upload_request,
+ std::string* rappor_metric_name) const;
// Returns metric relevant to the CVC field based on values in
// |found_cvc_field_|, |found_value_in_cvc_field_| and
@@ -432,13 +432,15 @@ class AutofillManager : public AutofillDownloadManager::Observer,
// Examines |card| and the stored profiles and if a candidate set of profiles
// is found that matches the client-side validation rules, assigns the values
- // to |profiles| and returns 0. If no valid set can be found, returns the
- // failure reasons and, if applicable, the RAPPOR metric to log to
- // |rappor_metric_name|. The return value is a bitmask of
+ // to |upload_request.profiles| and returns 0. If no valid set can be found,
+ // returns the failure reasons and, if applicable, the RAPPOR metric to log to
+ // |rappor_metric_name|. Appends any experiments that were triggered to
+ // |upload_request.active_experiments|. The return value is a bitmask of
// |AutofillMetrics::CardUploadDecisionMetric|.

Powered by Google App Engine
This is Rietveld 408576698